
.. _tutorials-writing-clients:

=====================
Writing Clients
=====================

The code for this example is located in the :mod:`examples.echo.manage`
module.

.. automodule:: examples.echo.manage

